# OzNetNerd Smart Check

Convenience Python module for Trend Micro [Smart Check](https://www.trendmicro.com/en_au/business/products/hybrid-cloud/smart-check-image-scanning.html).

# Documentation

Module documentation & examples can be found [here.](https://onnsc.oznetnerd.com/)

# Contact

* Blog: [oznetnerd.com](https://oznetnerd.com)
* Email: will@oznetnerd.com